%define shortver 84
%define majorver 8

# %%{_bindir}/nviz is included in grass
%global __requires_exclude nviz

# filter out devel requires as we have also devel .so files pkg'ed in main pkg
%global __devel_exclude_path %{_libdir}/%{name}%{shortver}/lib/libgrass_[a-zA-Z0-9]\+\\.so

Name:		grass
Version:	8.4.1
Release:	%mkrel 1
Group:		Sciences/Geosciences
Summary:	Geographic Resources Analysis Support System
License:	GPLv2+
URL:		https://grass.osgeo.org/
# https://github.com/OSGeo/grass/releases/download/%%{version}/%%{name}-%%{version}.tar.xz
Source0:	https://github.com/OSGeo/grass/archive/%{version}/%{name}-%{version}.tar.gz

# fix pkgconfig file
Patch0:		grass-pkgconfig.patch
# fix broken runtime path
Patch2:		grass-8.2.0-mga-fixpath.patch
#
BuildRequires:	appstream-util
BuildRequires:	pkgconfig(xmu)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	pkgconfig(gdlib) >= 2.0
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(cairo)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(fftw3)
BuildRequires:	tk
BuildRequires:	pkgconfig(tk)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	gdbm-devel
BuildRequires:	pkgconfig(readline)
BuildRequires:	postgresql-devel
BuildRequires:	gcc-gfortran
BuildRequires:	pkgconfig(gdal)
BuildRequires:	flex
BuildRequires:	swig
BuildRequires:	bison
BuildRequires:	pkgconfig(proj)
BuildRequires:	proj >= 4.4.7
BuildRequires:	tcl
BuildRequires:	pkgconfig(tcl)
BuildRequires:	lapack-devel
BuildRequires:	blas-devel
BuildRequires:	libgomp-devel
BuildRequires:	pkgconfig(cfitsio)
BuildRequires:	pkgconfig(odbc)
BuildRequires:	mysql-devel
BuildRequires:	termcap-devel
#BuildRequires:	ffmpeg-devel
BuildRequires:	pkgconfig(pdal)
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3dist(wxpython)
BuildRequires:	pkgconfig(sqlite3)
BuildRequires:	python3dist(numpy)
BuildRequires:	python3dist(six)
BuildRequires:	python3dist(python-dateutil)
BuildRequires:	imagemagick
BuildRequires:	lzma
BuildRequires:	pkgconfig(bzip2)
BuildRequires:	pkgconfig(libzstd)
BuildRequires:	pkgconfig(netcdf)
BuildRequires:	pkgconfig(OpenCL)

Requires:	xterm
Requires:	tk
Requires:	tcl
Requires:	python3-wxpython4


%description
GRASS (Geographic Resources Analysis Support System) is an
open source, Free Software Geographical Information System (GIS)
with raster, topological vector, image processing, and graphics
production functionality that operates on various platforms
through a graphical user interface and shell in X-Window.


%prep
%autosetup -p1


%build
%configure \
	--prefix=%{_libdir} \
	--with-libs=%{_libdir} \
	--with-includes=%{_includedir} \
	--with-postgres \
	--with-freetype \
	--with-freetype-includes=%{_includedir}/freetype2 \
	--with-cairo \
	--with-openmp \
	--with-lapack \
	--with-blas \
	--with-gdal \
	--with-geos \
	--with-mysql \
	--with-mysql-includes=%{_includedir}/mysql \
	--with-odbc \
	--with-sqlite \
	--with-cxx \
	--with-proj-share=%{_datadir}/proj \
	--with-nls \
	--with-readline \
	--with-bzlib \
	--with-zstd \
	--with-opencl \
	--with-netcdf
#   --with-ffmpeg --with-ffmpeg-includes="%%{_includedir}/libavcodec \
#   %%{_includedir}/libavdevice \
#   %%{_includedir}/libavformat %%{_includedir}/libavutil \
#   %%{_includedir}/libpostproc %%{_includedir}/libswscale"

%make_build


%install
mkdir -p %{buildroot}%{_bindir}
%make_install \
        prefix=%{_libdir} \
        UNIX_BIN=%{_bindir} \
        GISBASE_RUNTIME=%{_libdir}/%{name}%{shortver}

# fix paths:
# Change GISBASE in startup script
for I in %{buildroot}%{_bindir}/%{name} \
	%{buildroot}%{_libdir}/%{name}%{shortver}/include/Make/Platform.make \
	%{buildroot}%{_libdir}/%{name}%{shortver}/include/Make/Grass.make \
	%{buildroot}%{_libdir}/%{name}%{shortver}/demolocation/.grassrc%{shortver} \
	%{buildroot}%{_libdir}/%{name}%{shortver}/etc/fontcap; do
	sed -i \
		-e 's|%{buildroot}%{_libdir}/%{name}-%{version}|%{_libdir}/%{name}%{shortver}|g' \
		-e 's|%{buildroot}%{_libdir}/%{name}%{shortver}|%{_libdir}/%{name}%{shortver}|g' \
		-e 's|%{buildroot}%{_bindir}|%{_bindir}|g' \
		$I
done

# fix paths in grass.pc
sed -i -e 's|%{_prefix}/%{name}-%{version}|%{_libdir}/%{name}%{shortver}|g' \
	%{name}.pc

mkdir -p %{buildroot}%{_libdir}/pkgconfig
install -p -m 644 %{name}.pc %{buildroot}%{_libdir}/pkgconfig

# Make man pages available on the system, convert to utf8 and avoid name conflict
mkdir -p %{buildroot}%{_mandir}/man1
for man in $(ls %{buildroot}%{_libdir}/%{name}%{shortver}/docs/man/man1/*.1)
do
	iconv -f iso8859-1 -t utf8 $man > %{buildroot}%{_mandir}/man1/$(basename $man)"%{name}"
done

# Make desktop, appdata and icon files available on the system
cp -pr %{buildroot}%{_libdir}/%{name}%{shortver}/share/* %{buildroot}%{_datadir}/
desktop-file-validate %{buildroot}/%{_datadir}/applications/*.desktop
appstream-util validate-relax --nonet %{buildroot}/%{_datadir}/metainfo/org.osgeo.%{name}.appdata.xml

%if 0
# fix runtime GISBASE path
sed -i -e 's|@MGAGISBASE@|%{_libdir}/%{name}%{shortver}|g' \
	bin.%{_target_platform}/grass
cp bin.%{_target_platform}/grass %{buildroot}%{_bindir}/grass
chmod a+x %{buildroot}/usr/bin/grass

for i in {16,22,24,32,36,48,64,72,96,128,192}
do
  install -p -D dist.%{_target_platform}/gui/icons/%{name}-${i}x${i}.png %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps/%{name}.png
done
%endif

mkdir %{buildroot}%{_libdir}/%{name}%{shortver}/locks
chmod 1777 %{buildroot}%{_libdir}/%{name}%{shortver}/locks

mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{_real_vendor}-%{name}.desktop << EOF
[Desktop Entry]
Name=GRASS GIS %{majorver}
GenericName=Geographic Information System
Comment=Geographic Resources Analysis Support System
Exec=%{_bindir}/grass
TryExec=%{_bindir}/grass
Icon=%{name}
Terminal=true
Type=Application
Categories=Science;Geology;
EOF

# avoid duplicate desktop entries in the menu
rm -f %{buildroot}%{_datadir}/applications/%{name}.desktop

# Add custom lib path to ld.conf.so.d
mkdir -p %{buildroot}%_sysconfdir/ld.so.conf.d
cat > %{buildroot}%_sysconfdir/ld.so.conf.d/%{name}.conf << EOF
%{_libdir}/%{name}%{shortver}/lib
EOF


%files
%doc AUTHORS README.md
%license COPYING
%attr(0755,root,root) %{_bindir}/*
%{_sysconfdir}/ld.so.conf.d/*
%{_libdir}/%{name}%{shortver}/
%{_libdir}/pkgconfig/*
%{_datadir}/applications/*
%{_metainfodir}/*
%{_mandir}/man1/*
%{_iconsdir}/*/*/*/*


%changelog
* Thu Feb 27 2025 daviddavid <daviddavid> 8.4.1-1.mga10
+ Revision: 2153474
- new version: 8.4.1

* Wed Feb 05 2025 daviddavid <daviddavid> 8.4.0-3.mga10
+ Revision: 2145297
- rebuild for new gdal 3.10.1

* Fri Sep 27 2024 daviddavid <daviddavid> 8.4.0-2.mga10
+ Revision: 2101624
- rebuild for new pdal 2.8.0

* Sat Aug 03 2024 daviddavid <daviddavid> 8.4.0-1.mga10
+ Revision: 2083493
- new version: 8.4.0

* Tue Jul 02 2024 daviddavid <daviddavid> 8.3.2-3.mga10
+ Revision: 2079009
- rebuild for new pdal 2.7.2

* Mon Jun 24 2024 daviddavid <daviddavid> 8.3.2-2.mga10
+ Revision: 2076342
- rebuild for GDAL 3.9.0

* Tue Apr 23 2024 daviddavid <daviddavid> 8.3.2-1.mga10
+ Revision: 2060624
- new version: 8.3.2

* Thu Jan 04 2024 daviddavid <daviddavid> 8.3.1-2.mga10
+ Revision: 2027496
- rebuild for new gdal

* Thu Nov 02 2023 daviddavid <daviddavid> 8.3.1-1.mga10
+ Revision: 2003471
- new version: 8.3.1
- enable pdal support

* Wed Nov 01 2023 daviddavid <daviddavid> 8.2.0-7.mga10
+ Revision: 2003425
- rebuild for new gdal 3.7.2

* Mon Dec 12 2022 ns80 <ns80> 8.2.0-6.mga9
+ Revision: 1921040
- rebuild for new libtiff

* Tue Dec 06 2022 eatdirt <eatdirt> 8.2.0-5.mga9
+ Revision: 1918707
- Rebuild for new gdal

* Sat Oct 22 2022 ghibo <ghibo> 8.2.0-4.mga9
+ Revision: 1898556
- Rebuild because of BS problems
- Avoid duplicate entries in menus

* Sat Oct 22 2022 ghibo <ghibo> 8.2.0-2.mga9
+ Revision: 1898529
- Add missed BR
- add patch2 to fix broken runtime path and avoid slipping of builddir into startup script.
- spec file cleanup (remove obsolete protected commands).
- expose more files to _datadir (metainfodir, etc.).

* Sat Oct 22 2022 ghibo <ghibo> 8.2.0-1.mga9
+ Revision: 1898469
- Don't disable Werror_cflags anymore.
- Use prefix instead of INSTDIR in configure and install stages to avoid errors about /usr/grass82/lib rpath.
- Update to release 8.2.0.
- Remove patch0 (merged upstream)
- Fix URL of Source0.
- Prepare for adding PDAL support in config.

* Sat May 21 2022 wally <wally> 8.0.1-4.mga9
+ Revision: 1859634
- filter out even more devel requires

* Fri May 20 2022 wally <wally> 8.0.1-3.mga9
+ Revision: 1859579
- filter out devel requires as we have also devel .so files pkg'ed in main pkg

* Tue May 10 2022 eatdirt <eatdirt> 8.0.1-2.mga9
+ Revision: 1857466
- Fixing missing soname in imagery lib

* Sat May 07 2022 eatdirt <eatdirt> 8.0.1-1.mga9
+ Revision: 1856668
- Upgrade to version 8.0.1
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Sat Dec 11 2021 eatdirt <eatdirt> 7.8.5-2.mga9
+ Revision: 1761482
- Rebuild for new gdal

* Fri May 07 2021 daviddavid <daviddavid> 7.8.5-1.mga9
+ Revision: 1722120
- new version: 7.8.5

* Fri May 07 2021 daviddavid <daviddavid> 7.8.3-7.mga9
+ Revision: 1722064
- add patch to fix build with gdal >= 3.3
- rebuild for new gdal 3.3.0

* Thu Mar 25 2021 daviddavid <daviddavid> 7.8.3-6.mga9
+ Revision: 1710148
- rebuild for new gdal 3.2.2

* Mon Oct 26 2020 akien <akien> 7.8.3-5.mga8
+ Revision: 1639629
- Rebuild against libnetcdf18

* Thu Oct 01 2020 pterjan <pterjan> 7.8.3-4.mga8
+ Revision: 1631514
- Rebuild for new netcdf on arm

* Thu Jul 16 2020 daviddavid <daviddavid> 7.8.3-3.mga8
+ Revision: 1606462
- rebuild for new gdal 3.1.2

* Sat Jun 27 2020 joequant <joequant> 7.8.3-2.mga8
+ Revision: 1599666
- bump version
- fix buildroot errors

* Wed May 06 2020 daviddavid <daviddavid> 7.8.3-1.mga8
+ Revision: 1580970
- new version: 7.8.3

* Sat Apr 18 2020 daviddavid <daviddavid> 7.8.2-3.mga8
+ Revision: 1568589
- rebuild for new proj 7.0.0
+ eatdirt <eatdirt>
- Switch to python3
- Upgrade to version 7.8.2, rebuild for new libproj

* Sun Mar 15 2020 daviddavid <daviddavid> 7.8.1-4.mga8
+ Revision: 1556459
- rebuild for new gdal 3.0.4

* Tue Feb 18 2020 umeabot <umeabot> 7.8.1-3.mga8
+ Revision: 1542170
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Jan 04 2020 luigiwalser <luigiwalser> 7.8.1-2.mga8
+ Revision: 1475961
- rebuild for readline

* Sat Nov 09 2019 zezinho <zezinho> 7.8.1-1.mga8
+ Revision: 1458921
- new version 7.8.0

* Mon May 06 2019 daviddavid <daviddavid> 7.6.1-2.mga7
+ Revision: 1396575
- enable zstd and bzip2 support

* Wed Apr 17 2019 eatdirt <eatdirt> 7.6.1-1.mga7
+ Revision: 1392080
- Upgrade to version 7.6.1

* Mon Mar 11 2019 daviddavid <daviddavid> 7.6.0-4.mga7
+ Revision: 1374352
- switch to sqlite3

* Fri Mar 08 2019 eatdirt <eatdirt> 7.6.0-3.mga7
+ Revision: 1372790
- Fix build against new proj
- Rebuild for new proj

* Thu Mar 07 2019 eatdirt <eatdirt> 7.6.0-1.mga7
+ Revision: 1372173
- Upgrade to version 7.6.0

* Wed Jan 09 2019 eatdirt <eatdirt> 7.4.4-2.mga7
+ Revision: 1353638
- Fix hardcoded build directory in launcher

* Wed Jan 09 2019 eatdirt <eatdirt> 7.4.4-1.mga7
+ Revision: 1353488
- Upgrade to version 7.4.4

* Sun Sep 23 2018 umeabot <umeabot> 7.4.1-2.mga7
+ Revision: 1298070
- Mageia 7 Mass Rebuild

* Tue Jul 31 2018 eatdirt <eatdirt> 7.4.1-1.mga7
+ Revision: 1246400
- Upgrade to version 7.4.1

* Mon Jun 11 2018 daviddavid <daviddavid> 7.4.0-2.mga7
+ Revision: 1236276
- remove no more available BR lesstif-devel

* Mon Mar 19 2018 eatdirt <eatdirt> 7.4.0-1.mga7
+ Revision: 1210451
- Upgrade to version 7.4.0

* Sat Mar 17 2018 daviddavid <daviddavid> 7.2.2-3.mga7
+ Revision: 1210037
- rebuild for new proj 5.0.0

* Sat Dec 23 2017 wally <wally> 7.2.2-2.mga7
+ Revision: 1184224
- rebuild for new mariadb

* Tue Oct 31 2017 eatdirt <eatdirt> 7.2.2-1.mga7
+ Revision: 1175220
- Upgrade to version 7.2.2

* Wed Jun 22 2016 eatdirt <eatdirt> 7.0.4-3.mga6
+ Revision: 1037221
- Fix hardcoded build path in binaries

* Thu Jun 02 2016 daviddavid <daviddavid> 7.0.4-2.mga6
+ Revision: 1019840
- rebuild for wxgtk3.0 built with GTK2

* Fri May 20 2016 eatdirt <eatdirt> 7.0.4-1.mga6
+ Revision: 1017268
- Upgrade to version 7.0.4
- Upgrade to version 7.0.4

* Fri May 20 2016 tv <tv> 6.4.4-8.mga6
+ Revision: 1017106
- rebuild for new libproj

* Sun Jan 10 2016 wally <wally> 6.4.4-7.mga6
+ Revision: 920921
- rebuild for new gdal

* Mon Oct 05 2015 daviddavid <daviddavid> 6.4.4-6.mga6
+ Revision: 886351
- rebuild for new tcl/tk 8.6.4

* Tue Nov 25 2014 cjw <cjw> 6.4.4-5.mga5
+ Revision: 799065
- rebuild against postgresql9.4

* Sat Oct 18 2014 danf <danf> 6.4.4-4.mga5
+ Revision: 788262
- Added libgrass_rli.patch to fix bad package requires due to
  unversioned linking of libgrass_rli

* Wed Oct 15 2014 umeabot <umeabot> 6.4.4-3.mga5
+ Revision: 750182
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild
+ tv <tv>
- use %%global for req/prov exclude
- autoconvert to new prov/req excludes

* Sat Jul 05 2014 matteo <matteo> 6.4.4-1.mga5
+ Revision: 643832
- new stable version 6.4.4

* Sat Oct 19 2013 umeabot <umeabot> 6.4.3-2.mga4
+ Revision: 534269
- Mageia 4 Mass Rebuild

* Tue Sep 10 2013 fwang <fwang> 6.4.3-1.mga4
+ Revision: 477071
- fix convert
- disable ffmpeg as it still failed
- new version 6.4.3

* Mon Jun 03 2013 fwang <fwang> 6.4.2-6.mga4
+ Revision: 435944
- rebuild for new libpng
+ obgr_seneca <obgr_seneca>
- Rebuild for new geos

* Sat Jan 12 2013 umeabot <umeabot> 6.4.2-4.mga3
+ Revision: 352586
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Aug 26 2012 obgr_seneca <obgr_seneca> 6.4.2-3.mga3
+ Revision: 284165
- added patch for gcc 4.7
- Disabled ffmpeg support due to API changes in ffmpeg
- Can be reenabled when upstream fixes it
- Rebuild against libavcodec54
+ fwang <fwang>
- use autoreconf
- try to build with ffmpeg 0.11

* Wed Mar 07 2012 matteo <matteo> 6.4.2-1.mga2
+ Revision: 221324
- new version 6.4.2

* Mon Feb 13 2012 dmorgan <dmorgan> 6.4.1-12.mga2
+ Revision: 208362
- mesaglw-devel does not exist anymore, so remove from buildrequires

* Fri Dec 23 2011 fwang <fwang> 6.4.1-11.mga2
+ Revision: 186521
- rebuild for new libtiff

* Sat Dec 10 2011 eatdirt <eatdirt> 6.4.1-10.mga2
+ Revision: 180291
- Rebuilt for fftw-3.3

* Thu Dec 08 2011 fwang <fwang> 6.4.1-9.mga2
+ Revision: 178843
- rebuild for new odbc

* Thu Nov 03 2011 obgr_seneca <obgr_seneca> 6.4.1-8.mga2
+ Revision: 161927
- rebuild against new geos

* Tue Sep 27 2011 obgr_seneca <obgr_seneca> 6.4.1-7.mga2
+ Revision: 149568
- rebuild against new geos and changes in gdal

* Sat Sep 17 2011 matteo <matteo> 6.4.1-6.mga2
+ Revision: 144502
- added patch to support libpng15
+ fwang <fwang>
- wrong linkage for grass

* Fri Sep 16 2011 matteo <matteo> 6.4.1-5.mga2
+ Revision: 144291
- patch to let grass compile using libpng12 (atm grass do not compile with default libpng15)
+ fwang <fwang>
- rebuild for new libpng

* Mon Jul 11 2011 ahmad <ahmad> 6.4.1-4.mga2
+ Revision: 122159
- Add a _requires_exceptions for nviz, already included in grass

* Wed Jul 06 2011 fwang <fwang> 6.4.1-3.mga2
+ Revision: 119180
- rebuild for new tcl

* Tue Jun 28 2011 fwang <fwang> 6.4.1-2.mga2
+ Revision: 115123
- rebuild

* Fri Jun 24 2011 fwang <fwang> 6.4.1-1.mga2
+ Revision: 113060
- more ffmpeg 0.8 patch
- fix build with ffmpeg 0.8
- new version 6.4.1

* Tue Apr 26 2011 wally <wally> 6.4.0-9.mga1
+ Revision: 91669
- fix desktop file (mga#954)

* Wed Apr 20 2011 obgr_seneca <obgr_seneca> 6.4.0-8.mga1
+ Revision: 89183
- rebuild agains new libgdal-1.8.0

* Wed Mar 30 2011 ahmad <ahmad> 6.4.0-7.mga1
+ Revision: 79121
- modify wx-config path in the configure option
+ ennael <ennael>
- clean spec file
- imported package grass


* Thu Mar 17 2011 Oden Eriksson <oeriksson@mandriva.com> 6.4.0-6mdv2011.0
+ Revision: 645802
- relink against libmysqlclient.so.18

* Sat Jan 01 2011 Oden Eriksson <oeriksson@mandriva.com> 6.4.0-5mdv2011.0
+ Revision: 627245
- rebuilt against mysql-5.5.8 libs, again

* Thu Dec 30 2010 Oden Eriksson <oeriksson@mandriva.com> 6.4.0-4mdv2011.0
+ Revision: 626526
- rebuilt against mysql-5.5.8 libs

* Sat Sep 04 2010 Funda Wang <fwang@mandriva.org> 6.4.0-2mdv2011.0
+ Revision: 575937
- rebuild

* Sat Sep 04 2010 Funda Wang <fwang@mandriva.org> 6.4.0-1mdv2011.0
+ Revision: 575716
- more specific ffmpeg includes dir
- drop old patches
- bunzip2 images
- 6.4.0 final

* Sun Apr 04 2010 Funda Wang <fwang@mandriva.org> 6.4.0-0.RC6.1mdv2010.1
+ Revision: 531071
- fix linkage on python binding
- new version 6.4.0RC6

* Fri Jun 12 2009 Funda Wang <fwang@mandriva.org> 6.4.0-0.RC5.1mdv2010.0
+ Revision: 385530
- New version 6.4.0 RC5

* Mon Apr 13 2009 Funda Wang <fwang@mandriva.org> 6.4.0-0.RC4.1mdv2009.1
+ Revision: 366560
- 6.4 rc 4

* Thu Mar 05 2009 Guillaume Rousse <guillomovitch@mandriva.org> 6.4.0-0.RC3.3mdv2009.1
+ Revision: 349189
- rebuild for latest readline

  + Funda Wang <fwang@mandriva.org>
    - update URL

* Tue Jan 27 2009 Funda Wang <fwang@mandriva.org> 6.4.0-0.RC3.2mdv2009.1
+ Revision: 334142
- fix linkage of cairo module
- fix cairo detection
- support cairo and pgsql

* Mon Jan 26 2009 Funda Wang <fwang@mandriva.org> 6.4.0-0.RC3.1mdv2009.1
+ Revision: 333828
- fix typo
- cleanup spec
- fix ldconf content
- drop old patches
- specify host also
- New version 6.4.0 RC3
- fix mislead sscanf
- fix typo
- final patch
- draft patch of tcl 8.6
- only freetype2 is needed
- more patch
- more patch
- 6.4.0 rc2
- more generic detection
- enalbe 64 bit
- add more patches
- first step to make it built
- clean spec

  + Oden Eriksson <oeriksson@mandriva.com>
    - rebuilt against mysql-5.1.30 libs

  + Buchan Milne <bgmilne@mandriva.org>
    - Rebuild for cfitsio change in library version
    - Fix ffmpeg and postgresql include paths
    - Enable readline support explicitly

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Wed Feb 13 2008 Helio Chissini de Castro <helio@mandriva.com> 6.2.3-2mdv2008.1
+ Revision: 167061
- Added proper ld.so.conf.d entry to allow applications like qgis knew that grass is available

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

  + Funda Wang <fwang@mandriva.org>
    - New version 6.2.3

* Fri Sep 07 2007 Anssi Hannula <anssi@mandriva.org> 6.2.2-4mdv2008.0
+ Revision: 82015
- rebuild for new soname of tcl

* Wed Sep 05 2007 Buchan Milne <bgmilne@mandriva.org> 6.2.2-3mdv2008.0
+ Revision: 80437
- Fix proj data location (last of #33149)
- Remove unused blas buildrequires and blas-related patches

* Thu Jul 19 2007 Adam Williamson <awilliamson@mandriva.org> 6.2.2-2mdv2008.0
+ Revision: 53402
- rebuild with new lesstif
- lzma not bzip manpages
- drop X-Mandriva menu category
- fd.o icons

* Tue Jul 17 2007 Funda Wang <fwang@mandriva.org> 6.2.2-1mdv2008.0
+ Revision: 52948
- New version


* Tue Feb 06 2007 Buchan Milne <bgmilne@mandriva.org> 6.2.1-3mdv2007.0
+ Revision: 116819
- Enable a few more features

* Fri Dec 15 2006 Buchan Milne <bgmilne@mandriva.org> 6.2.1-2mdv2007.1
+ Revision: 97418
- buildrequire termcap-devel
- build system cant handle package name different to module name
-New version 6.2.1
-use versioned name on backports
-obsolete this versioned one in the cooker package to take care of upgrades
-drop irrelevant patches

  + Nicolas Lécureuil <neoclust@mandriva.org>
    - Add BuildRequires

* Thu Aug 31 2006 Buchan Milne <bgmilne@mandriva.org> 6.0.2-1mdv2007.0
+ Revision: 58796
- Import grass

* Wed Aug 30 2006 Buchan Milne <bgmilne@mandriva.org> 6.0.2-1mdv2007.0
- 6.0.2
- fix buildrequires and lib/include paths for xorg 7.0 and later
- disable glw on 2007 and later until I can find the problem
- xdg menu

* Fri Feb 03 2006 Lenny Cartier <lenny@mandriva.com> 6.0.2-0.RC4.1mdk
- 6.0.2RC4

* Mon Jan 02 2006 Oden Eriksson <oeriksson@mandriva.com> 6.0.1-4mdk
- rebuilt against soname aware deps (tcl/tk)
- fix deps

* Tue Oct 04 2005 Nicolas Lécureuil <neoclust@mandriva.org> 6.0.1-3mdk
- Fix BuildRequires

* Tue Oct 04 2005 Nicolas Lécureuil <neoclust@mandriva.org> 6.0.1-2mdk
Fix BuildRequires

* Sun Oct 02 2005 Lenny Cartier <lenny@mandriva.com> 6.0.1-1mdk
- 6.0.1

* Wed May 04 2005 Nicolas Lécureuil <neoclust@mandriva.org> 6.0.0-3mdk
- Rebuild ( Fix #15790)

* Wed Mar 16 2005 Buchan Milne <bgmilne@linux-mandrake.com> 6.0.0-2mdk
- rebuild

* Tue Mar 15 2005 Buchan Milne <bgmilne@linux-mandrake.com> 6.0.0-1mdk
- 6.0.0
- better requires
- cleanups and merge with changes in grass57
- use mkrel
- obsolete grass57

* Sat Jul 17 2004 Buchan Milne <bgmilne@linux-mandake.com> 5.0.3-3mdk
- rebuild for gcc-3.4

